@@ -3,7 +3,7 @@ from .mdi import MDI_COMMAND_LENGTH, MDI_NAME_LENGTH, MDI_LABEL_LENGTH, \
     MDI_INT, MDI_INT8_T, MDI_INT16_T, MDI_INT32_T, MDI_INT64_T, \
     MDI_UINT8_T, MDI_UINT16_T, MDI_UINT32_T, MDI_UINT64_T, \
     MDI_DOUBLE, MDI_CHAR, MDI_FLOAT, MDI_BYTE, \
-    MDI_TCP, MDI_MPI, MDI_LINK, MDI_TEST, \
+    MDI_TCP, MDI_MPI, MDI_LINK, MDI_PLUGIN, MDI_TEST, \
     MDI_DRIVER, MDI_ENGINE, \
     MDI_MAJOR_VERSION, MDI_MINOR_VERSION, MDI_PATCH_VERSION, \
     MDI_Init, MDI_Accept_Communicator, \
@@ -17,6 +17,7 @@ from .mdi import MDI_COMMAND_LENGTH, MDI_NAME_LENGTH, MDI_LABEL_LENGTH, \
     MDI_Register_Callback, MDI_Check_Callback_Exists, MDI_Get_NCallbacks, MDI_Get_Callback, \
     MDI_Accept_communicator, MDI_Send_command, MDI_Recv_command, MDI_Conversion_factor, \
     MDI_Get_role, MDI_Set_execute_command_func, \
+    MDI_Get_method, MDI_Get_communicator, \
     MDI_Register_node, MDI_Check_node_exists, MDI_Get_nnodes, MDI_Get_node, \
     MDI_Register_command, MDI_Check_command_exists, MDI_Get_ncommands, MDI_Get_command, \
     MDI_Register_callback, MDI_Check_callback_exists, MDI_Get_ncallbacks, MDI_Get_callback, \
